pub struct PartneredEstimate {
pub amount: Box<Amount>,
pub confirm_deadline: Option<String>,
pub void_deadline: Option<String>,
}Expand description
PartneredEstimate : The estimated shipping cost for a shipment using an Amazon-partnered carrier.
Fields
amount: Box<Amount>confirm_deadline: Option<String>void_deadline: Option<String>Implementations
sourceimpl PartneredEstimate
impl PartneredEstimate
sourcepub fn new(amount: Amount) -> PartneredEstimate
pub fn new(amount: Amount) -> PartneredEstimate
The estimated shipping cost for a shipment using an Amazon-partnered carrier.